@@ -13,7 +13,9 @@ from rdflib.plugins.sparql.processor import SPARQLResult
 from rdflib.tools.rdf2dot import rdf2dot
 
 from octadocs.conversions import iri_by_page
-from octadocs.environment import iri_to_url, query, src_path_to_iri
+from octadocs.environment import iri_to_url, src_path_to_iri
+from octadocs.octiron.types import LOCAL
+from octadocs.query import query
 
 
 def graph(instance: rdflib.ConjunctiveGraph) -> str:
@@ -141,6 +143,8 @@ def define_env(env: MacrosPlugin) -> MacrosPlugin:  # noqa: WPS213
     env.filter(turtle)
     env.filter(table)
 
+    octiron = env.variables.octiron
+
     env.macro(
         partial(
             query,
@@ -188,11 +192,8 @@ def define_env(env: MacrosPlugin) -> MacrosPlugin:  # noqa: WPS213
     env.filter(iri_by_page)
     env.macro(iri_by_page)
 
-    # FIXME this is hardcode, needs to be defined dynamically
-    env.variables['rdfs'] = rdflib.Namespace(
-        'http://www.w3.org/2000/01/rdf-schema#',
-    )
-    env.variables['local'] = rdflib.Namespace('local:')
+    # Update context with namespaces
+    env.variables.update(octiron.namespaces)
 
     env.variables['URIRef'] = rdflib.URIRef
 
